@@ -233,8 +233,6 @@ Write out the results of this driver's operations to the specified file.
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-geometry-primitive at rt.cpan.org>, or through
@@ -243,9 +241,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
\ No newline at end of file
